matminer.learners package — matminer 0.1.3 documentation

# matminer.learners package

## Subpackages

- matminer.learners.tests package
  - Submodules
  - matminer.learners.tests.test_volume_predictor module
  - Module contents

## Submodules

## matminer.learners.volume_predictor module

class `matminer.learners.volume_predictor.` `ConditionalVolumePredictor`

  Unlike the above, the idea here is to predict the volume of a structure based on an existing known structure. May integrate with above at a later stage to improve overall predictions.

  `__init__`()
  `get_predicted_structure`(structure, ref_structure)

    Given a structure, returns back the structure scaled to predicted volume.

    Args:

      structure (Structure): structure w/unknown volume ref_structure (Structure): A reference structure with a similar

      > structure but different species.

    Returns:
      a Structure object with predicted volume
  `predict`(structure, ref_structure, test_isostructural=True)

    Given a structure, returns back the predicted volume.

    Args:

      structure (Structure): structure w/unknown volume ref_structure (Structure): A reference structure with a similar

      > structure but different species.

      test_isostructural (bool): Whether to test that the two
        structures are isostructural. This algo works best for isostructural compounds. Defaults to True.
    Returns:
      a float value of the predicted volume

class `matminer.learners.volume_predictor.` `VolumePredictor`(cutoff=4, ionic_factor=0.3)

  Predicts volume; given a structure, finds the minimum volume such that no two sites are closer than a weighted sum of their atomic and ionic radii. When run over all stable elemental and binary structures from MP, it is found that: (i) RMSE % error = 23.6 % (ii) Average percentage difference in volume from initial volume = 2.88 % (iii) Average absolute percentage difference in volume from initial volume = 17.0 % (iv) Performs worst for materials that are gaseous eg: H2, N2,

  > and f-electron systems, eg: Np, Pu, etc. as well as noble gas compounds

  This is really intended for bonded systems!

  `__init__`(cutoff=4, ionic_factor=0.3)
    Args:
      cutoff (float): cutoff radius added to site radius for finding
        site pairs. Necessary to increase only if your initial structure guess is extremely bad (atoms way too far apart). In all other instances, increasing cutoff gives same answer but takes more time.
      ionic_factor: (float) This factor, multiplied by the compound’s
        spread in electronegativity, determines the weighting between ionic and atomic radii for expected bond distances.
  `get_predicted_structure`(structure)

    Given a structure, returns back the structure scaled to predicted volume.

    Args:
      structure (Structure): structure w/unknown volume
    Returns:
      a Structure object with predicted volume
  `predict`(structure)

    Given a structure, returns back the predicted volume.

    Args:
      structure (Structure): structure w/unknown volume
    Returns:
      a float value of the predicted volume

`matminer.learners.volume_predictor.` `is_ox`(structure)

## Module contents